@@ -12,14 +12,13 @@ sub birthday     { Time::Piece->new( '1990/04/04', '%Y/%m/%d' ) }
 sub age          { 14 }
 sub blood_type   {'B'}
 sub challenge {
-    qw(
-       光の使者、キュアブラック! 
-       光の使者、キュアホワイト! 
-       ふたりはプリキュア! 
-       闇の力の僕たちよ! 
-       とっととおうちに帰りなさい!
-    )
+    "\e[38;5;255m\e[48;5;232m光の使者、キュアブラック!\e[0m",
+    "\e[38;5;232m\e[48;5;255m光の使者、キュアホワイト!\e[0m",
+    "\e[38;5;201mふたりはプリキュア!\e[0m",
+    "\e[38;5;232m\e[48;5;255m闇の力の僕たちよ!\e[0m",
+    "\e[38;5;255m\e[48;5;232mとっととおうちに帰りなさい!\e[0m",
 }
+sub color { 255 }
 
 before 'transform' => sub {
     my ($self, $buddy) = @_;
